/*
** atariints.h -- Atari Linux interrupt handling structs and prototypes
**
** Copyright 1994 by Bjrn Brauel
**
** 5/2/94 Roman Hodek:
**   TT interupt definitions added.
**
** This file is subject to the terms and conditions of the GNU General Public
** License.  See the file README.legal in the main directory of this archive
** for more details.
**
*/

#ifndef _LINUX_ATARIINTS_H_
#define _LINUX_ATARIINTS_H_

/*
** Atari Interrupt sources.
**
*/

#define STMFP_SOURCE_BASE   0
#define TTMFP_SOURCE_BASE   16
#define SCC_SOURCE_BASE	    32
#define	VME_SOURCE_BASE		48
#define	VME_MAX_SOURCES		16

#define NUM_ATARI_SOURCES   (VME_SOURCE_BASE+VME_MAX_SOURCES)

/* offset of auto-vector int source# to vector# */
#define	ATARI_AUTOVECTOR_OFFSET	0x18

/* offset of source# to vector# */
#define	ATARI_VECTOR_OFFSET	0x40


#define IRQ_MFP_BUSY      (IRQ_MACHSPEC | 0)
#define IRQ_MFP_DCD       (IRQ_MACHSPEC | 1)
#define IRQ_MFP_CTS  	  (IRQ_MACHSPEC | 2)
#define IRQ_MFP_GPU 	  (IRQ_MACHSPEC | 3)
#define IRQ_MFP_TIMD      (IRQ_MACHSPEC | 4)
#define IRQ_MFP_TIMC	  (IRQ_MACHSPEC | 5)
#define IRQ_MFP_ACIA	  (IRQ_MACHSPEC | 6)
#define IRQ_MFP_FDC       (IRQ_MACHSPEC | 7)
#define IRQ_MFP_TIMB      (IRQ_MACHSPEC | 8)
#define IRQ_MFP_SERERR    (IRQ_MACHSPEC | 9)
#define IRQ_MFP_SEREMPT   (IRQ_MACHSPEC | 10)
#define IRQ_MFP_RECERR    (IRQ_MACHSPEC | 11)
#define IRQ_MFP_RECFULL   (IRQ_MACHSPEC | 12)
#define IRQ_MFP_TIMA      (IRQ_MACHSPEC | 13)
#define IRQ_MFP_RI        (IRQ_MACHSPEC | 14)
#define IRQ_MFP_MMD       (IRQ_MACHSPEC | 15)

#define IRQ_TT_MFP_IO0       (IRQ_MACHSPEC | 16)
#define IRQ_TT_MFP_IO1       (IRQ_MACHSPEC | 17)
#define IRQ_TT_MFP_SCC	     (IRQ_MACHSPEC | 18)
#define IRQ_TT_MFP_RI 	     (IRQ_MACHSPEC | 19)
#define IRQ_TT_MFP_TIMD      (IRQ_MACHSPEC | 20)
#define IRQ_TT_MFP_TIMC	     (IRQ_MACHSPEC | 21)
#define IRQ_TT_MFP_DRVRDY    (IRQ_MACHSPEC | 22)
#define IRQ_TT_MFP_SCSIDMA   (IRQ_MACHSPEC | 23)
#define IRQ_TT_MFP_TIMB      (IRQ_MACHSPEC | 24)
#define IRQ_TT_MFP_SERERR    (IRQ_MACHSPEC | 25)
#define IRQ_TT_MFP_SEREMPT   (IRQ_MACHSPEC | 26)
#define IRQ_TT_MFP_RECERR    (IRQ_MACHSPEC | 27)
#define IRQ_TT_MFP_RECFULL   (IRQ_MACHSPEC | 28)
#define IRQ_TT_MFP_TIMA      (IRQ_MACHSPEC | 29)
#define IRQ_TT_MFP_RTC       (IRQ_MACHSPEC | 30)
#define IRQ_TT_MFP_SCSI      (IRQ_MACHSPEC | 31)

#define	IRQ_SCCB_TX	     (IRQ_MACHSPEC | 32)
#define	IRQ_SCCB_STAT	     (IRQ_MACHSPEC | 34)
#define	IRQ_SCCB_RX	     (IRQ_MACHSPEC | 36)
#define	IRQ_SCCB_SPCOND	     (IRQ_MACHSPEC | 38)
#define	IRQ_SCCA_TX	     (IRQ_MACHSPEC | 40)
#define	IRQ_SCCA_STAT	     (IRQ_MACHSPEC | 42)
#define	IRQ_SCCA_RX	     (IRQ_MACHSPEC | 44)
#define	IRQ_SCCA_SPCOND	     (IRQ_MACHSPEC | 46)

#define INT_CLK   24576	    /* CLK while int_clk =2.456MHz and divide = 100 */
#define INT_TICKS 246	    /* to make sched_time = 99.902... HZ */

int atari_int_set_edge_triggered( unsigned long source, int flag );
unsigned long atari_register_vme_int( void );

/* Use software EOI mode of the MFPs? */
#undef	ATARI_USE_SOFTWARE_EOI

#endif /* linux/atariints.h */
